@@ -146,6 +146,7 @@ coreMTME <- function(Y, X, Z1, Z2, nIter, burnIn, thin, bs, digits, progressBar,
 
   #######Function for block sampling of norma-multivariate data#######
   rmv_f <- function(ps, c, A, x) {
+    A    <- (A + t(A))/2
     p    <- dim(A)[1L]
     k    <- floor(p / ps) # Numbers of blocks
     r1   <- p - k * ps
@@ -162,7 +163,7 @@ coreMTME <- function(Y, X, Z1, Z2, nIter, burnIn, thin, bs, digits, progressBar,
       EigenA <- eigen(A_ii)
       d_A    <- EigenA$values
       V_A    <- EigenA$vectors
-      pos_A1 <- which(d_A > 1e-10)
+      pos_A1 <- which(Re(d_A) > 1e-10)
       if (identical(pos_A1, integer(0))) {
         pos_A <- 1L
       } else {
@@ -193,7 +194,7 @@ coreMTME <- function(Y, X, Z1, Z2, nIter, burnIn, thin, bs, digits, progressBar,
         EigenA <- eigen(A_ii)
         d_A <- EigenA$values
         V_A <- EigenA$vectors
-        pos_A1 <- which(d_A > 1e-10)
+        pos_A1 <- which(Re(d_A) > 1e-10)
         if (identical(pos_A1, integer(0))) {
           pos_A <- 1L
         } else {
